@@ -21,8 +21,8 @@ models <- list(linear = NULL, emax = 25,
 planMM(models, doses, n = rep(50,6), alpha = 0.05, scal=200)
 #powerMM(models, doses, base = 0, maxEff = 0.4, sigma = 1,       
 #        lower = 10, upper = 100, step = 20, scal = 200, alpha = 0.05)
-sampSize(models, doses, base = 0, maxEff = 0.4, sigma = 1,             
-         upperN = 80, scal = 200, alpha = 0.05)
+#sampSize(models, doses, base = 0, maxEff = 0.4, sigma = 1,             
+#         upperN = 80, scal = 200, alpha = 0.05)
 #LP(models, model = "emax", type = "both", paramRange = c(10,70),
 #    doses = doses, base = 0, maxEff = 0.4, sigma = 1, n = 60,
 #    alpha = 0.05, len = 15, scal = 200)
